# PUDIP-Flow

PUDIP-Flow — Phase Unwrapping via Deep Image Prior for 4D Flow MRI.

## Installation

```bash
pip install pudipflow
```

## Reproducible Demo
A step-by-step example is provided in `test.ipynb`.

The file `./TestData.h5` is a test dataset extracted from the source of FlowVN : https://codeocean.com/capsule/0115983/tree/v1
